==> tuia-advert-center-api-2.5.09-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/promotetest/AdvertPromoteTestDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.promotetest;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

import java.util.Date;

/**测试落地页返回虚体参数
 * Created by jzl on 18/5/14.
 */
public class AdvertPromoteTestDto extends BaseDto {

    private static final long serialVersionUID = 4495104563533960093L;
    /** 广告ID **/
    private Long advertId;

    /** 定向配置ID*/
    private Long orientPackageId;

    /** 测试落地页url **/
    private String promoteUrl;

    /** 测试落地页名称 **/
    private String promoteName;

    /** 匹配的素材ID集合 ,分割**/
    private String materialIds;

    /** 状态 0审核中 1审核通过 2审核拒绝 默认0**/
    private Integer status;

    /** 审核拒绝原因 **/
    private String rejectReason;

    //落地页类型：0-A/BTest,1-新媒体投放链接
    private Integer urlType;

    /** 投放开始时间 **/
    private String startDateStr;

    /** 投放结束时间 **/
    private String endDateStr;

    /** 权重 流量占比 **/
    private Double weight;

    /** 测试 落地页选的配置 **/
    private String orientIds;

    //分流模式：1=PV、2=UV
    private Integer shuntMode;

    private Date enterCheckTime;

    /**
     * 审核人
     */
    private String auditor;

    /**
     * 审核时间
     */
    private Date auditTime;

    /** 关键词命中标签,多个使用英文逗号隔开 **/
    private String wordHitTag;

    /** '内控审核落地页标签' **/
    private String promoteTag;

    //数据来源id 比如积木那边创建的落地页id   必填
    private  Long  sourceId;

    //平台系统 1积木 2百奇    必填
    private Integer sourceType;

    /**
     * 是否自定义分流比例:0/null 否，1-是
     */
    private Integer isCustom;

    /**
     * 自定义分流比例
     */
    private Integer splitFlow;
    /**域名备案*/
    private String icpName;

    public String getIcpName() {
        return icpName;
    }

    public void setIcpName(String icpName) {
        this.icpName = icpName;
    }
    public Integer getIsCustom() {
        return isCustom;
    }

    public void setIsCustom(Integer isCustom) {
        this.isCustom = isCustom;
    }

    public Integer getSplitFlow() {
        return splitFlow;
    }

    public void setSplitFlow(Integer splitFlow) {
        this.splitFlow = splitFlow;
    }

    public String getOrientIds() {
        return orientIds;
    }

    public void setOrientIds(String orientIds) {
        this.orientIds = orientIds;
    }

    public Long getOrientPackageId() {
        return orientPackageId;
    }

    public void setOrientPackageId(Long orientPackageId) {
        this.orientPackageId = orientPackageId;
    }

    public String getPromoteName() {
        return promoteName;
    }

    public void setPromoteName(String promoteName) {
        this.promoteName = promoteName;
    }

    public Integer getUrlType() {
        return urlType;
    }

    public void setUrlType(Integer urlType) {
        this.urlType = urlType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public String getMaterialIds() {
        return materialIds;
    }

    public void setMaterialIds(String materialIds) {
        this.materialIds = materialIds;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getRejectReason() {
        return rejectReason;
    }

    public void setRejectReason(String rejectReason) {
        this.rejectReason = rejectReason;
    }

    public String getStartDateStr() {
        return startDateStr;
    }

    public void setStartDateStr(String startDateStr) {
        this.startDateStr = startDateStr;
    }

    public String getEndDateStr() {
        return endDateStr;
    }

    public void setEndDateStr(String endDateStr) {
        this.endDateStr = endDateStr;
    }

    public Double getWeight() {
        return weight;
    }

    public void setWeight(Double weight) {
        this.weight = weight;
    }

    public Integer getShuntMode() {
        return shuntMode;
    }

    public void setShuntMode(Integer shuntMode) {
        this.shuntMode = shuntMode;
    }

    public Date getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(Date enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getAuditor() {
        return auditor;
    }

    public void setAuditor(String auditor) {
        this.auditor = auditor;
    }

    public Date getAuditTime() {
        return auditTime;
    }

    public void setAuditTime(Date auditTime) {
        this.auditTime = auditTime;
    }

    public String getWordHitTag() {
        return wordHitTag;
    }

    public void setWordHitTag(String wordHitTag) {
        this.wordHitTag = wordHitTag;
    }

    public String getPromoteTag() {
        return promoteTag;
    }

    public void setPromoteTag(String promoteTag) {
        this.promoteTag = promoteTag;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
}

==> tuia-advert-center-api-2.5.50-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/promotetest/AdvertPromoteTestDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.promotetest;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

import java.util.Date;

/**测试落地页返回虚体参数
 * Created by jzl on 18/5/14.
 */
public class AdvertPromoteTestDto extends BaseDto {

    private static final long serialVersionUID = 4495104563533960093L;
    /** 广告ID **/
    private Long advertId;

    /** 定向配置ID*/
    private Long orientPackageId;

    /** 测试落地页url **/
    private String promoteUrl;

    /** 测试落地页名称 **/
    private String promoteName;

    /** 匹配的素材ID集合 ,分割**/
    private String materialIds;

    /** 状态 0审核中 1审核通过 2审核拒绝 默认0**/
    private Integer status;

    /** 审核拒绝原因 **/
    private String rejectReason;

    //落地页类型：0-A/BTest,1-新媒体投放链接
    private Integer urlType;

    /** 投放开始时间 **/
    private String startDateStr;

    /** 投放结束时间 **/
    private String endDateStr;

    /** 权重 流量占比 **/
    private Double weight;

    /** 测试 落地页选的配置 **/
    private String orientIds;

    //分流模式：1=PV、2=UV
    private Integer shuntMode;

    private Date enterCheckTime;

    /**
     * 审核人
     */
    private String auditor;

    /**
     * 审核时间
     */
    private Date auditTime;

    /** 关键词命中标签,多个使用英文逗号隔开 **/
    private String wordHitTag;

    /** '内控审核落地页标签' **/
    private String promoteTag;

    //数据来源id 比如积木那边创建的落地页id   必填
    private  Long  sourceId;

    //平台系统 1积木 2百奇    必填
    private Integer sourceType;

    /**
     * 是否自定义分流比例:0/null 否，1-是
     */
    private Integer isCustom;

    /**
     * 自定义分流比例
     */
    private Integer splitFlow;
    /**域名备案*/
    private String icpName;

    /** 素材总数 **/
    private Integer totalMaterialNum;

    /** 可投素材数量 **/
    private Integer validMaterialNum;

    public String getIcpName() {
        return icpName;
    }

    public void setIcpName(String icpName) {
        this.icpName = icpName;
    }
    public Integer getIsCustom() {
        return isCustom;
    }

    public void setIsCustom(Integer isCustom) {
        this.isCustom = isCustom;
    }

    public Integer getSplitFlow() {
        return splitFlow;
    }

    public void setSplitFlow(Integer splitFlow) {
        this.splitFlow = splitFlow;
    }

    public String getOrientIds() {
        return orientIds;
    }

    public void setOrientIds(String orientIds) {
        this.orientIds = orientIds;
    }

    public Long getOrientPackageId() {
        return orientPackageId;
    }

    public void setOrientPackageId(Long orientPackageId) {
        this.orientPackageId = orientPackageId;
    }

    public String getPromoteName() {
        return promoteName;
    }

    public void setPromoteName(String promoteName) {
        this.promoteName = promoteName;
    }

    public Integer getUrlType() {
        return urlType;
    }

    public void setUrlType(Integer urlType) {
        this.urlType = urlType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public String getMaterialIds() {
        return materialIds;
    }

    public void setMaterialIds(String materialIds) {
        this.materialIds = materialIds;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getRejectReason() {
        return rejectReason;
    }

    public void setRejectReason(String rejectReason) {
        this.rejectReason = rejectReason;
    }

    public String getStartDateStr() {
        return startDateStr;
    }

    public void setStartDateStr(String startDateStr) {
        this.startDateStr = startDateStr;
    }

    public String getEndDateStr() {
        return endDateStr;
    }

    public void setEndDateStr(String endDateStr) {
        this.endDateStr = endDateStr;
    }

    public Double getWeight() {
        return weight;
    }

    public void setWeight(Double weight) {
        this.weight = weight;
    }

    public Integer getShuntMode() {
        return shuntMode;
    }

    public void setShuntMode(Integer shuntMode) {
        this.shuntMode = shuntMode;
    }

    public Date getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(Date enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getAuditor() {
        return auditor;
    }

    public void setAuditor(String auditor) {
        this.auditor = auditor;
    }

    public Date getAuditTime() {
        return auditTime;
    }

    public void setAuditTime(Date auditTime) {
        this.auditTime = auditTime;
    }

    public String getWordHitTag() {
        return wordHitTag;
    }

    public void setWordHitTag(String wordHitTag) {
        this.wordHitTag = wordHitTag;
    }

    public String getPromoteTag() {
        return promoteTag;
    }

    public void setPromoteTag(String promoteTag) {
        this.promoteTag = promoteTag;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Integer getTotalMaterialNum() {
        return totalMaterialNum;
    }

    public void setTotalMaterialNum(Integer totalMaterialNum) {
        this.totalMaterialNum = totalMaterialNum;
    }

    public Integer getValidMaterialNum() {
        return validMaterialNum;
    }

    public void setValidMaterialNum(Integer validMaterialNum) {
        this.validMaterialNum = validMaterialNum;
    }
}
